@@ -2,12 +2,10 @@
 
 import datetime
 import logging
-import re
-import sys
 
 from moe.library.lib_item import LibItem
 
-__all__ = ["edit_item", "EditError"]
+__all__ = ["EditError", "edit_item"]
 
 log = logging.getLogger("moe.edit")
 
@@ -44,19 +42,9 @@ def edit_item(item: LibItem, field: str, value: str):
     elif isinstance(attr, int):
         setattr(item, field, int(value))
     elif isinstance(attr, datetime.date):
-        if (sys.version_info.major, sys.version_info.minor) < (3, 7):
-            if not re.match(
-                r"^\d{4}-([0]\d|1[0-2])-([0-2]\d|3[01])$", value  # noqa: FS003
-            ):
-                raise EditError("Date must be in format YYYY-MM-DD")
-            date = value.split("-")
-            setattr(
-                item, field, datetime.date(int(date[0]), int(date[1]), int(date[2]))
-            )
-        else:
-            try:
-                setattr(item, field, datetime.date.fromisoformat(value))
-            except ValueError as v_err:
-                raise EditError("Date must be in format YYYY-MM-DD") from v_err
+        try:
+            setattr(item, field, datetime.date.fromisoformat(value))
+        except ValueError as v_err:
+            raise EditError("Date must be in format YYYY-MM-DD") from v_err
     else:
         raise EditError(f"Editing field of type '{type(attr)}' not supported.")
